# Matrix Report
### On this page
  * [How is it useful?](https://help.sap.com/docs/leanix/ea/matrix-report#how-is-it-useful?)
  * [Using Matrix Reports](https://help.sap.com/docs/leanix/ea/matrix-report#using-matrix-reports)
  * [Filters, Views, and Levels](https://help.sap.com/docs/leanix/ea/matrix-report#filters,-views,-and-levels)
  * [Drill-Down](https://help.sap.com/docs/leanix/ea/matrix-report#drill-down)
  * [Views on Drilled-Down Fact Sheets](https://help.sap.com/docs/leanix/ea/matrix-report#views-on-drilled-down-fact-sheets)
  * [Layout Modes](https://help.sap.com/docs/leanix/ea/matrix-report#layout-modes)
  * [Editing in Matrix Reports](https://help.sap.com/docs/leanix/ea/matrix-report#editing-in-matrix-reports)


Matrix reports give you a color-coded matrix view that represents a correlation between 3 different fact sheet types. You can use this report to analyze your portfolio on various dimensions at various points in time. For example, to answer a question such as: “Which applications that support the ‘Account Management' capability will soon reach the 'End of life' for the 'Europe' user group?”. SAP LeanIX provides several examples of matrix reports, as you will discover in the later section. This documentation focuses more on the application matrix report to ensure ease of understanding.
In the example of the application matrix report, you can see that each cell represents the application fact sheet as the base of the report, which has active relations to other fact sheets set in the X and Y axis, in this case, business capabilities and user groups.
![View of Application Matrix Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27422f517a441014bdf8dc8ebce1c483_LowRes.png)
View of Application Matrix Report
